SystemOrganization addCategory: #'SUnit-Extensions'!
SystemOrganization addCategory: #'SUnit-Kernel'!
SystemOrganization addCategory: #'SUnit-Tests'!
SystemOrganization addCategory: #'SUnit-Utilities'!

Trait named: #TAssertable
	uses: {}
	category: 'SUnit-Kernel'!

!TAssertable methodsFor: 'asserting' stamp: 'jannik.laval 5/2/2010 07:34'!
assert: aBoolean

	aBoolean ifFalse: [self signalFailure: 'Assertion failed']
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/25/2009 00:23'!
assert: aBooleanOrBlock description: aStringOrBlock
	aBooleanOrBlock value ifFalse: [
		| message |
		message := aStringOrBlock value.
		TestResult failure signal: message]
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/28/2009 20:50'!
assert: aBooleanOrBlock description: aString resumable: resumableBoolean 
	| exception |
	aBooleanOrBlock value
		ifFalse: 
			[TestResult failure new
				isResumable: resumableBoolean;
				signal: aString]
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
assert: expected equals: actual
	^ self
		assert: (expected = actual)
		description: (self comparingStringBetween: expected and: actual)
! !

!TAssertable methodsFor: 'private' stamp: 'AdrianKuhn 12/24/2009 01:27'!
comparingStringBetween: expected and: actual
	^ String streamContents: [:stream |
		stream
			nextPutAll: 'Expected ';
			nextPutAll: (expected printStringLimitedTo: 10);
			nextPutAll: ' but was ';
			nextPutAll: (actual printStringLimitedTo: 10);
			nextPutAll: '.'
		]! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
deny: aBooleanOrBlock

	self assert: aBooleanOrBlock value not
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
deny: aBooleanOrBlock description: aString
	self assert: aBooleanOrBlock value not description: aString
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
deny: aBooleanOrBlock description: aString resumable: resumableBoolean 
	self
		assert: aBooleanOrBlock value not
		description: aString
		resumable: resumableBoolean
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:26'!
executeShould: aBlock inScopeOf: anExceptionalEvent 
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: true]
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:26'!
executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: aString
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: (ex description includesSubString: aString) ]
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:26'!
executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: aString
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: (ex description includesSubString: aString) not ]
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:26'!
executeShould: aBlock inScopeOf: anException withExceptionDo: anotherBlock

	^[aBlock value.
 	false] 
		on: anException
		do: [:exception | 
			anotherBlock value: exception.
			exception return: true]! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:28'!
fail

	^self assert: false! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
should: aBlock
	self assert: aBlock value
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
should: aBlock description: aString
	self assert: aBlock value description: aString
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:29'!
should: aBlock notTakeMoreThan: aDuration
    "Evaluate aBlock in a forked process and if it takes more than anInteger milliseconds
    to run we terminate the process and report a test failure.  It'' important to
    use the active process for the test failure so that the failure reporting works correctly
    in the context of the exception handlers."

    | evaluated evaluationProcess result delay testProcess |

    evaluated := false.
    delay := Delay forDuration: aDuration.
    testProcess := Processor activeProcess.
    "Create a new process to evaluate aBlock"
    evaluationProcess := [
        result := aBlock value.
        evaluated := true.
        delay unschedule.
        testProcess resume ] forkNamed: 'Process to evaluate should: notTakeMoreThanMilliseconds:'.

    "Wait the milliseconds they asked me to"
    delay wait.
    "After this point either aBlock was evaluated or not..."
    evaluated ifFalse: [
        evaluationProcess terminate.
        self assert: false description: ('Block evaluation took more than the expected <1p>' expandMacrosWith: aDuration)].
   
    ^result! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:29'!
should: aBlock notTakeMoreThanMilliseconds: anInteger
    "For compatibility with other Smalltalks"

   self should: aBlock notTakeMoreThan: (Duration milliSeconds: anInteger).! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
should: aBlock raise: anExceptionalEvent 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent)
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
should: aBlock raise: anExceptionalEvent description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent)
		description: aString
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
should: aBlock raise: anExceptionalEvent whoseDescriptionDoesNotInclude: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: subString)
		description: aString
! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
should: aBlock raise: anExceptionalEvent whoseDescriptionIncludes: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: subString)
		description: aString
! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:29'!
should: aBlock raise: anException withExceptionDo: anotherBlock 

	^self assert: (self executeShould: aBlock inScopeOf: anException withExceptionDo: anotherBlock)! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/24/2009 01:29'!
shouldFix: aBlock 

	^self should: aBlock raise: Exception! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
shouldnt: aBlock
	self deny: aBlock value
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
shouldnt: aBlock description: aString
	self deny: aBlock value description: aString
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
shouldnt: aBlock raise: anExceptionalEvent 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent) not
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
shouldnt: aBlock raise: anExceptionalEvent description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent) not 		description: aString
			! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
shouldnt: aBlock raise: anExceptionalEvent whoseDescriptionDoesNotInclude: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: subString) not
		description: aString
! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
shouldnt: aBlock raise: anExceptionalEvent whoseDescriptionIncludes: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: subString) not
		description: aString
! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/21/2009 14:56'!
signalFailure: aString
	TestResult failure signal: aString! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/29/2009 17:11'!
skip
	^ self skipUnless: false.! !

!TAssertable methodsFor: 'asserting' stamp: 'AdrianKuhn 12/29/2009 17:11'!
skipUnless: aBooleanOrBlock
	" If the assumption in aBooleanOrBlock is not true, abandon the running test
	and mark it as passed. "
	aBooleanOrBlock value ifFalse:
			[ TestFailure newSkipped signal: 'Assumption in #skipUnless: failed' ]! !

Exception subclass: #TestFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestFailure commentStamp: '<historical>' prior: 0!
Signaled in case of a failed test (failure). The test framework distinguishes between failures and errors. A failure is anticipated and checked for with assertions. Errors are unanticipated problems like a division by 0 or an index out of bounds ...!

TestFailure subclass: #ResumableTestFailure
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!ResumableTestFailure commentStamp: '<historical>' prior: 0!
A ResumableTestFailure triggers a TestFailure, but lets execution of the TestCase continue. this is useful when iterating through collections, and #assert: ing on each element. in combination with methods like testcase>>#assert:description:, this lets you run through a whole collection and note which tests pass.

here''s an example:

	

	(1 to: 30) do: [ :each |
		self assert: each odd description: each printString, ' is even' resumable: true]

for each element where #odd returns <false>, the element will be printed to the Transcript. !

!ResumableTestFailure methodsFor: 'camp smalltalk' stamp: ''!
isResumable
	"Of course a ResumableTestFailure is resumable ;-)"

	^true! !

!ResumableTestFailure methodsFor: 'camp smalltalk' stamp: ''!
sunitExitWith: aValue
	self resume: aValue! !

!TestFailure methodsFor: 'camp smalltalk' stamp: 'ajh 1/24/2003 19:23'!
defaultAction

	Processor activeProcess
		debug: self signalerContext
		title: self description! !

!TestFailure methodsFor: 'camp smalltalk' stamp: 'ajh 2/1/2003 00:58'!
isResumable
	
	^ false! !

Object subclass: #BadEqualer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!BadEqualer commentStamp: 'mjr 8/20/2003 13:28' prior: 0!
I am an object that doesn't always report #= correctly.  Used for testing the EqualityTester.!

!BadEqualer methodsFor: 'comparing' stamp: 'mjr 8/20/2003 18:56'!
= other 
	self class = other class
		ifFalse: [^ false].
	^ 100 atRandom < 30 ! !

Object subclass: #BadHasher
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!BadHasher commentStamp: 'mjr 8/20/2003 13:28' prior: 0!
I am an object that doesn't always hash correctly.  I am used for testing the HashTester.!

!BadHasher methodsFor: 'comparing' stamp: 'mjr 8/20/2003 18:56'!
hash
	"answer with a different hash some of the time"
	100 atRandom < 30
		ifTrue: [^ 1]. 
	^ 2! !

Object subclass: #ClassFactoryForTestCase
	instanceVariableNames: 'createdClasses'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!ClassFactoryForTestCase methodsFor: 'cleaning' stamp: 'Noury 10/26/2008 16:26'!
cleanUp
	| createdClassNames |
	createdClassNames := self createdClassNames.
	self deleteClasses.
	self deletePackage.
	self cleanUpChangeSetForClassNames: createdClassNames! !

!ClassFactoryForTestCase methodsFor: 'cleaning' stamp: 'Noury 10/26/2008 14:20'!
cleanUpChangeSetForClassNames: classeNames
	| changeSet |
	changeSet := ChangeSet current.
	classeNames do: [:name|
		changeSet 
			removeClassChanges: name;
			removeClassChanges: name, ' class'].	! !

!ClassFactoryForTestCase methodsFor: 'accessing' stamp: 'Noury 10/26/2008 14:21'!
createdClassNames
	^self createdClasses collect: [:class| class name]! !

!ClassFactoryForTestCase methodsFor: 'accessing' stamp: 'Noury 10/26/2008 13:59'!
createdClasses
	^createdClasses! !

!ClassFactoryForTestCase methodsFor: 'accessing' stamp: 'Noury 10/26/2008 14:01'!
createdClasses: classes
	createdClasses := classes asIdentitySet ! !

!ClassFactoryForTestCase methodsFor: 'accessing' stamp: 'Noury 10/26/2008 16:37'!
defaultCategory
	^ (self packageName , '-', self defaultCategoryPostfix) asSymbol! !

!ClassFactoryForTestCase methodsFor: 'accessing' stamp: 'Noury 10/26/2008 16:23'!
defaultCategoryPostfix
	^ #Default! !

!ClassFactoryForTestCase methodsFor: 'cleaning' stamp: 'Noury 10/26/2008 12:47'!
delete: aClass
	aClass isObsolete ifTrue: [^self].
	aClass removeFromChanges.
	aClass removeFromSystemUnlogged
! !

!ClassFactoryForTestCase methodsFor: 'cleaning' stamp: 'Noury 10/26/2008 12:46'!
deleteClasses
	self createdClasses do: [:class|
		self delete: class]! !

!ClassFactoryForTestCase methodsFor: 'cleaning' stamp: 'Noury 10/26/2008 16:33'!
deletePackage
	| categoriesMatchString |
	categoriesMatchString := self packageName, '-*'.
	SystemOrganization removeCategoriesMatching: categoriesMatchString! !

!ClassFactoryForTestCase methodsFor: 'cleaning' stamp: 'Noury 10/26/2008 14:01'!
initialize
	super initialize.
	self createdClasses: IdentitySet new! !

!ClassFactoryForTestCase methodsFor: 'creating' stamp: 'Noury 10/26/2008 14:55'!
newClass
	^self newSubclassOf: Object instanceVariableNames: '' classVariableNames: ''! !

!ClassFactoryForTestCase methodsFor: 'creating' stamp: 'Noury 10/26/2008 16:46'!
newClassInCategory: category
	^self newSubclassOf: Object instanceVariableNames: '' classVariableNames: '' category: category! !

!ClassFactoryForTestCase methodsFor: 'creating' stamp: 'Noury 11/12/2009 17:53'!
newName
	| postFix |
	postFix := (self createdClasses size + 1) printString.
	^(#ClassForTestToBeDeleted, postFix) asSymbol! !

!ClassFactoryForTestCase methodsFor: 'creating' stamp: 'Noury 10/26/2008 16:25'!
newSubclassOf: aClass instanceVariableNames: ivNamesString classVariableNames:  classVarsString 
	^self 
		newSubclassOf: aClass 
		instanceVariableNames: ivNamesString 
		classVariableNames: classVarsString 
		category: self defaultCategoryPostfix! !

!ClassFactoryForTestCase methodsFor: 'creating' stamp: 'Noury 10/26/2008 16:36'!
newSubclassOf: aClass instanceVariableNames: ivNamesString classVariableNames:  classVarsString category: category
	| newClass |
	newClass := aClass 
		subclass: self newName 
		instanceVariableNames: ivNamesString 
		classVariableNames: classVarsString 
		poolDictionaries: '' 
		category: (self packageName, '-', category) asSymbol.
	self createdClasses add: newClass.
	^newClass! !

!ClassFactoryForTestCase methodsFor: 'accessing' stamp: 'Noury 10/26/2008 16:20'!
packageName
	^#CategoryForTestToBeDeleted! !

Object subclass: #PrototypeTester
	instanceVariableNames: 'prototype'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!PrototypeTester commentStamp: 'mjr 8/20/2003 13:09' prior: 0!
I am a simple holder of a prototype object and hand out copies when requested.!

PrototypeTester subclass: #EqualityTester
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!EqualityTester commentStamp: 'mjr 8/20/2003 13:04' prior: 0!
I provide a simple way to test the equality properties of any object.!

!EqualityTester methodsFor: 'as yet unclassified' stamp: 'mjr 8/20/2003 18:56'!
resultFor: runs 
	"Test that equality is the same over runs and answer the result"
	1
		to: runs
		do: [:i | self prototype = self prototype
				ifFalse: [^ false]]. 
	^ true! !

PrototypeTester subclass: #HashTester
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!HashTester commentStamp: 'mjr 8/20/2003 12:48' prior: 0!
I provide a simple way to test the hash properties of any object.  

I am given an object that should be tested and I treat it like a prototype.  I take a copy of it when I am given it so that it can't change whilst I am holding on to it.  I can then test that multiple copies of this object all hash to the same value.!

!HashTester methodsFor: 'as yet unclassified' stamp: 'stephaneducasse 2/3/2006 22:39'!
resultFor: runs 
	"Test that the hash is the same over runs and answer the result"
	| hash |
	hash := self prototype hash.
	1
		to: runs
		do: [:i | hash = self prototype hash
				ifFalse: [^ false]].
	^ true ! !

!PrototypeTester class methodsFor: 'as yet unclassified' stamp: 'mjr 8/20/2003 13:08'!
defaultRuns
"the default number of times to test"
	^ 50! !

!PrototypeTester class methodsFor: 'as yet unclassified' stamp: 'mjr 8/20/2003 13:08'!
with: aPrototype
	^self new prototype:aPrototype! !

!PrototypeTester methodsFor: 'as yet unclassified' stamp: 'mjr 8/20/2003 18:56'!
prototype
	"Get a prototype"
	^ prototype copy ! !

!PrototypeTester methodsFor: 'as yet unclassified' stamp: 'stephaneducasse 2/3/2006 22:39'!
prototype: aPrototype 
	"Set my prototype"
	prototype := aPrototype copy ! !

!PrototypeTester methodsFor: 'as yet unclassified' stamp: 'mjr 8/20/2003 18:57'!
result
	"Perform the test the default number of times"
	^ self resultFor: self class defaultRuns ! !

Object subclass: #TestCase
	instanceVariableNames: 'testSelector'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

TestCase class
	instanceVariableNames: 'history'!

!TestCase commentStamp: '<historical>' prior: 0!
A TestCase is a Command representing the future running of a test case. Create one with the class method #selector: aSymbol, passing the name of the method to be run when the test case runs.

When you discover a new fixture, subclass TestCase, declare instance variables for the objects in the fixture, override #setUp to initialize the variables, and possibly override# tearDown to deallocate any external resources allocated in #setUp.

When you are writing a test case method, send #assert: aBoolean when you want to check for an expected value. For example, you might say "self assert: socket isOpen" to test whether or not a socket is open at a point in a test.!

TestCase class
	instanceVariableNames: 'history'!

TestCase subclass: #ClassFactoryForTestCaseTest
	instanceVariableNames: 'factory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!ClassFactoryForTestCaseTest class methodsFor: 'history' stamp: 'simon.denier 11/22/2008 22:13'!
lastStoredRun
	^ ((Dictionary new) add: (#passed->((Set new) add: #testDefaultCategoryCleanUp; add: #testPackageCleanUp; add: #testSingleClassCreation; add: #testClassCreationInDifferentCategories; add: #testClassFastCreationInDifferentCategories; add: #testMultipleClassCreation; add: #testSingleClassFastCreation; yourself)); add: (#timeStamp->'22 November 2008 10:11:35 pm'); add: (#failures->((Set new))); add: (#errors->((Set new))); yourself)! !

!ClassFactoryForTestCaseTest methodsFor: 'setUp-tearDown' stamp: 'Noury 10/26/2008 12:19'!
setUp
	super setUp.
	factory := ClassFactoryForTestCase new! !

!ClassFactoryForTestCaseTest methodsFor: 'setUp-tearDown' stamp: 'Noury 10/26/2008 14:53'!
tearDown
	super tearDown.
	factory cleanUp! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'Noury 10/26/2008 16:43'!
testClassCreationInDifferentCategories
	| firstThreeClasses lastTwoClasses |
	3 timesRepeat: [
		factory newSubclassOf: Object instanceVariableNames: '' classVariableNames: '' category: #One].
	firstThreeClasses := factory createdClasses copy.
	2 timesRepeat: [
		factory newSubclassOf: Object instanceVariableNames: '' classVariableNames: '' category: #Two].
	lastTwoClasses := factory createdClasses copyWithoutAll: firstThreeClasses.
	self assert: (firstThreeClasses allSatisfy: [:class| class category = (factory packageName, '-', #One) asSymbol]).
	self assert: (lastTwoClasses allSatisfy: [:class| class category = (factory packageName, '-', #Two) asSymbol]).! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'Noury 10/26/2008 16:42'!
testClassFastCreationInDifferentCategories
	| firstThreeClasses lastTwoClasses |
	3 timesRepeat: [
		factory newClassInCategory: #One].
	firstThreeClasses := factory createdClasses copy.
	2 timesRepeat: [
		factory newClassInCategory: #Two].
	lastTwoClasses := factory createdClasses copyWithoutAll: firstThreeClasses.
	self assert: (firstThreeClasses allSatisfy: [:class| class category = (factory packageName, '-', #One) asSymbol]).
	self assert: (lastTwoClasses allSatisfy: [:class| class category = (factory packageName, '-', #Two) asSymbol]).! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'Noury 10/26/2008 16:44'!
testDefaultCategoryCleanUp
	| createdClassNames allClasses |
	3 timesRepeat: [
		factory newClass].
	createdClassNames := factory createdClassNames.
	factory cleanUp.	
	self assert: (factory createdClasses allSatisfy: [:class| class isObsolete]). 
	allClasses := SystemNavigation new allClasses.
	self assert: (factory createdClasses noneSatisfy: [:class| allClasses includes: class]).
	self deny: (SystemOrganization categories includes: factory defaultCategory). 
	self deny: (ChangeSet current changedClassNames includesAnyOf: createdClassNames)
! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'Noury 10/26/2008 16:38'!
testMultipleClassCreation
	5 timesRepeat: [
		factory newClass].
	self assert: (SystemNavigation new allClasses includesAllOf: factory createdClasses).
	self assert: factory createdClassNames asSet size = 5.
	self assert: (SystemOrganization listAtCategoryNamed: factory defaultCategory) asSet = factory createdClassNames asSet! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'Noury 10/26/2008 16:47'!
testPackageCleanUp
	| createdClassNames allClasses |
	3 timesRepeat: [
		factory newClassInCategory: #One].
	2 timesRepeat: [
		factory newClassInCategory: #Two].
	createdClassNames := factory createdClassNames.
	factory cleanUp.	
	self assert: (factory createdClasses allSatisfy: [:class| class isObsolete]). 
	allClasses := SystemNavigation new allClasses.
	self assert: (factory createdClasses noneSatisfy: [:class| allClasses includes: class]).
	self assert: (SystemOrganization categoriesMatching: factory packageName, '*') isEmpty. 
	self deny: (ChangeSet current changedClassNames includesAnyOf: createdClassNames)
! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'nice 12/3/2009 23:47'!
testSingleClassCreation
	|class elementsInCategoryForTest |
	class := factory 
		newSubclassOf: Object 
		instanceVariableNames: 'a b c' 
		classVariableNames: 'X Y'.
	self assert: (SystemNavigation new allClasses includes: class).
	elementsInCategoryForTest := SystemOrganization listAtCategoryNamed: factory defaultCategory. 
	self assert: elementsInCategoryForTest = {class name}.
	self assert: class instVarNames = #(a b c).
	self assert: class classPool keys asSet = #(X Y) asSet! !

!ClassFactoryForTestCaseTest methodsFor: 'testing' stamp: 'Noury 10/26/2008 16:37'!
testSingleClassFastCreation
	|class elementsInCategoryForTest |
	class := factory newClass.
	self assert: (SystemNavigation new allClasses includes: class).
	elementsInCategoryForTest := SystemOrganization listAtCategoryNamed: factory defaultCategory. 
	self assert: elementsInCategoryForTest = {class name}.
	self assert: class instVarNames isEmpty.
	self assert: class classPool isEmpty! !

TestCase subclass: #ClassTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!ClassTestCase commentStamp: 'brp 7/26/2003 16:57' prior: 0!
This class is intended for unit tests of individual classes and their metaclasses.

It provides methods to determine the coverage of the unit tests.

Subclasses are expected to re-implement #classesToBeTested and #selectorsToBeIgnored.

They should also implement to confirm that all methods have been tested.

#testCoverage

	super testCoverage.

!

!ClassTestCase class methodsFor: 'testing' stamp: 'md 2/22/2006 14:21'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #ClassTestCase
			! !

!ClassTestCase class methodsFor: 'testing' stamp: 'brp 12/14/2003 15:50'!
mustTestCoverage

	^ false! !

!ClassTestCase methodsFor: 'private' stamp: 'md 1/28/2004 11:32'!
categoriesForClass: aClass

 ^ aClass organization allMethodSelectors collect: 
			[:each |  aClass organization categoryOfElement: each].
! !

!ClassTestCase methodsFor: 'coverage' stamp: 'brp 7/27/2003 12:39'!
classToBeTested
	
	self subclassResponsibility! !

!ClassTestCase methodsFor: 'coverage' stamp: 'brp 7/26/2003 16:35'!
selectorsNotTested

	^ self selectorsToBeTested difference: self selectorsTested.
! !

!ClassTestCase methodsFor: 'Coverage' stamp: 'MarcusDenker 3/5/2010 14:33'!
selectorsTested
	| literals |
	literals := Set new.
	self class
		selectorsAndMethodsDo: [ :s :m | (s beginsWith: 'test')
			ifTrue: [ literals addAll: (m messages)] ].
	^ literals asArray sort! !

!ClassTestCase methodsFor: 'coverage' stamp: 'brp 7/26/2003 17:22'!
selectorsToBeIgnored
	^ #(#DoIt #DoItIn:)! !

!ClassTestCase methodsFor: 'coverage' stamp: 'brp 7/27/2003 12:40'!
selectorsToBeTested

	^ ( { self classToBeTested. self classToBeTested class } gather: [:c | c selectors]) 
			difference: self selectorsToBeIgnored! !

!ClassTestCase methodsFor: 'private' stamp: 'lr 3/14/2010 21:13'!
targetClass
	[ ^ self classToBeTested ]
		on: Error
		do: [ 
			| className |
			className := self class name asText copyFrom: 0 to: self class name size - 4.
			^ Smalltalk globals at: className asString asSymbol ]! !

!ClassTestCase methodsFor: 'tests' stamp: 'marcus.denker 7/29/2009 15:27'!
testClassComment
	self should: [self targetClass organization hasComment].! !

!ClassTestCase methodsFor: 'tests' stamp: 'brp 12/14/2003 15:51'!
testCoverage

	| untested | 
	self class mustTestCoverage ifTrue:
		[ untested := self selectorsNotTested.
		self assert: untested isEmpty 
		description: untested size asString, ' selectors are not covered' ]! !

!ClassTestCase methodsFor: 'tests' stamp: 'md 3/25/2003 23:07'!
testNew
	self shouldnt: [self targetClass new] raise: Error.! !

!ClassTestCase methodsFor: 'tests' stamp: 'md 3/26/2003 17:24'!
testUnCategorizedMethods
	| categories slips  |
	categories := self categoriesForClass: self targetClass.
	slips := categories select: [:each | each = #'as yet unclassified'].
	self should: [slips isEmpty].	! !

TestCase subclass: #HashAndEqualsTestCase
	instanceVariableNames: 'prototypes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!HashAndEqualsTestCase commentStamp: 'mjr 8/20/2003 17:37' prior: 0!
I am a simple TestCase that tests for correct operation of #hash and #=.

Subclasses of me need to fill my prototypes with suitable objects to be tested.!

!HashAndEqualsTestCase methodsFor: 'running' stamp: 'stephaneducasse 2/3/2006 22:39'!
setUp
	"subclasses will add their prototypes into this collection"
	prototypes := OrderedCollection new ! !

!HashAndEqualsTestCase methodsFor: 'testing' stamp: 'mjr 8/20/2003 18:56'!
testEquality
	"Check that TextFontChanges report equality correctly"
	prototypes
		do: [:p | self
				should: [(EqualityTester with: p) result]] ! !

!HashAndEqualsTestCase methodsFor: 'testing' stamp: 'al 6/12/2008 21:58'!
testHash
	"test that TextFontChanges hash correctly"
	prototypes do: [:p |
		self should: [(HashTester with: p) result]] ! !

TestCase subclass: #HashTesterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Utilities'!

!HashTesterTest commentStamp: 'mjr 8/20/2003 12:48' prior: 0!
I am a simple test case to check that HashTester works correctly!

!HashTesterTest methodsFor: 'as yet unclassified' stamp: 'mjr 8/20/2003 18:56'!
testBasicBehaviour
	self
		should: [(HashTester with: 1)
				resultFor: 100].
	self
		should: [(HashTester with: 'fred')
				resultFor: 100].
	self
		shouldnt: [(HashTester with: BadHasher new)
				resultFor: 100] ! !

TestCase subclass: #LongTestCase
	instanceVariableNames: ''
	classVariableNames: 'DoNotRunLongTestCases'
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!LongTestCase class methodsFor: 'accessing' stamp: 'md 12/5/2004 21:36'!
allTestSelectors
	DoNotRunLongTestCases ifFalse: [
		^super testSelectors].
	^#().! !

!LongTestCase class methodsFor: 'instance creation' stamp: 'stephaneducasse 2/3/2006 22:41'!
buildSuite
	| suite |
	suite := TestSuite new.
	DoNotRunLongTestCases ifFalse: [
		self addToSuiteFromSelectors: suite].
	^suite! !

!LongTestCase class methodsFor: 'accessing' stamp: 'sd 9/25/2004 12:57'!
doNotRunLongTestCases

	DoNotRunLongTestCases := true.! !

!LongTestCase class methodsFor: 'initialization' stamp: 'sd 9/25/2004 12:57'!
initialize

	self doNotRunLongTestCases! !

!LongTestCase class methodsFor: 'testing' stamp: 'md 2/22/2006 14:21'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #LongTestCase
			! !

!LongTestCase class methodsFor: 'accessing' stamp: 'md 11/14/2004 21:31'!
runLongTestCases

	DoNotRunLongTestCases := false.! !

LongTestCase subclass: #LongTestCaseTestUnderTest
	instanceVariableNames: ''
	classVariableNames: 'RunStatus'
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!LongTestCaseTestUnderTest class methodsFor: 'accessing' stamp: 'sd 9/25/2004 14:02'!
hasRun

	^ RunStatus! !

!LongTestCaseTestUnderTest class methodsFor: 'accessing' stamp: 'md 11/14/2004 21:37'!
markAsNotRun

	^ RunStatus := false! !

!LongTestCaseTestUnderTest methodsFor: 'testing' stamp: 'md 11/14/2004 21:30'!
testWhenRunMarkTestedToTrue


	RunStatus := true.! !

TestCase subclass: #LongTestCaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Extensions'!

!LongTestCaseTest methodsFor: 'testing' stamp: 'sd 9/25/2004 14:12'!
testLongTestCaseDoNotRun
	"self debug: #testLongTestCaseDoNotRun"
	"self run: #testLongTestCaseDoNotRun"

	LongTestCase doNotRunLongTestCases.
	LongTestCaseTestUnderTest markAsNotRun.
	self deny: LongTestCaseTestUnderTest hasRun.
	LongTestCaseTestUnderTest suite run.
	self deny: LongTestCaseTestUnderTest hasRun.


	! !

!LongTestCaseTest methodsFor: 'testing' stamp: 'md 12/5/2004 21:28'!
testLongTestCaseRun
	"self debug: #testLongTestCaseRun"
	"self run: #testLongTestCaseRun"

	LongTestCase runLongTestCases.
	LongTestCaseTestUnderTest markAsNotRun.
	self deny: LongTestCaseTestUnderTest hasRun.
	LongTestCaseTestUnderTest suite run.
	self assert: LongTestCaseTestUnderTest hasRun.
	LongTestCase doNotRunLongTestCases.

	! !

TestCase subclass: #ResumableTestFailureTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!ResumableTestFailureTestCase class methodsFor: 'history' stamp: 'simon.denier 11/22/2008 22:13'!
lastStoredRun
	^ ((Dictionary new) add: (#passed->((Set new) add: #testResumable; yourself)); add: (#timeStamp->'22 November 2008 10:11:35 pm'); add: (#failures->((Set new))); add: (#errors->((Set new))); yourself)! !

!ResumableTestFailureTestCase methodsFor: 'not categorized' stamp: ''!
errorTest
	1 zork
			! !

!ResumableTestFailureTestCase methodsFor: 'not categorized' stamp: ''!
failureTest
	self
		assert: false description: 'You should see me' resumable: true; 
		assert: false description: 'You should see me too' resumable: true; 
		assert: false description: 'You should see me last' resumable: false; 
		assert: false description: 'You should not see me' resumable: true
			! !

!ResumableTestFailureTestCase methodsFor: 'not categorized' stamp: ''!
okTest
	self assert: true
			! !

!ResumableTestFailureTestCase methodsFor: 'not categorized' stamp: ''!
regularTestFailureTest
	self assert: false description: 'You should see me'
			! !

!ResumableTestFailureTestCase methodsFor: 'not categorized' stamp: ''!
resumableTestFailureTest
	self
		assert: false description: 'You should see me' resumable: true; 
		assert: false description: 'You should see me too' resumable: true; 
		assert: false description: 'You should see me last' resumable: false; 
		assert: false description: 'You should not see me' resumable: true
			! !

!ResumableTestFailureTestCase methodsFor: 'not categorized' stamp: ''!
testResumable
	| result suite |
	suite := TestSuite new.
	suite addTest: (self class selector: #errorTest).
	suite addTest: (self class selector: #regularTestFailureTest).
	suite addTest: (self class selector: #resumableTestFailureTest).
	suite addTest: (self class selector: #okTest).
	result := suite run.
	self assert: result failures size = 2;
		assert: result errors size = 1
			! !

TestCase subclass: #SUnitExtensionsTest
	instanceVariableNames: 'stream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SUnitExtensionsTest class methodsFor: 'history' stamp: 'simon.denier 11/22/2008 22:13'!
lastStoredRun
	^ ((Dictionary new) add: (#passed->((Set new) add: #testNoExceptionWithMatchingString; add: #testNoExceptionWithNoMatchingString; add: #testExceptionWithMatchingString; add: #testExceptionWithoutMatchingString; add: #testValidShouldNotTakeMoreThan; add: #testInvalidShouldNotTakeMoreThanMilliseconds; add: #testDifferentExceptionInShouldRaiseWithExceptionDo; add: #testShouldRaiseWithExceptionDo; add: #testShouldFix; add: #testAssertionFailedInRaiseWithExceptionDo; add: #testAutoDenyFalse; add: #testAutoDenyTrue; add: #testAutoAssertFalse; add: #testAutoAssertTrue; add: #testValidShouldNotTakeMoreThanMilliseconds; add: #testErrorInRaiseWithExceptionDo; add: #testNoExceptionInShouldRaiseWithExceptionDo; add: #testInvalidShouldNotTakeMoreThan; yourself)); add: (#timeStamp->'22 November 2008 10:11:35 pm'); add: (#failures->((Set new))); add: (#errors->((Set new))); yourself)! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
assertionFailedInRaiseWithExceptionDoTest

	self 
		should: [ Error signal ]
		raise: Error
		withExceptionDo: [ :anException | self assert: false ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
differentExceptionInShouldRaiseWithExceptionDoTest

	[ self 
		should: [ Error signal ]
		raise: Halt
		withExceptionDo: [ :anException | self assert: false description: 'should:raise:withExceptionDo: handled an exception that should not handle'] ]
	on: Error
	do: [ :anException | anException return: nil ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
errorInRaiseWithExceptionDoTest

	self 
		should: [ Error  signal ]
		raise: Error
		withExceptionDo: [ :anException | Error signal: 'A forced error' ]! !

!SUnitExtensionsTest methodsFor: 'test support' stamp: ''!
failureLog
	^self stream! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'md 8/2/2006 11:04'!
invalidShouldNotTakeMoreThan

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThan: 50 milliSeconds.! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: ''!
invalidShouldNotTakeMoreThanMilliseconds

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThanMilliseconds: 50! !

!SUnitExtensionsTest methodsFor: 'testing' stamp: ''!
isLogging
	^true! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
noExceptionInShouldRaiseWithExceptionDoTest

	self 
		should: [  ]
		raise: Error
		withExceptionDo: [ :anException | Error signal: 'Should not get here' ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: ''!
shouldFixTest

	self shouldFix: [ Error signal: 'any kind of error' ]
! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
shouldRaiseWithExceptionDoTest

	self 
		should: [ Error signal: '1' ]
		raise: Error
		withExceptionDo: [ :anException | self assert: anException messageText = '1' ]! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'mx 3/20/2006 23:47'!
shouldRaiseWithSignalDoTest

	self 
		should: [ Error signal: '1' ]
		raise: Error
		withExceptionDo: [ :anException | self assert: anException messageText = '1' ]! !

!SUnitExtensionsTest methodsFor: 'accessing' stamp: 'PeterHugossonMiller 9/3/2009 11:09'!
stream
	stream isNil ifTrue: [stream := String new writeStream].
	^stream! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:39'!
testAssertionFailedInRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #assertionFailedInRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult failures includes: testCase).
	self assert: testResult failures size=1.
	self assert: testResult passed isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 21:15'!
testAutoAssertFalse
	| booleanCondition |
	self assert: self isLogging.
	self should: [ self assert: 1 = 2 description: 'self assert: 1 = 2' ] raise: TestResult failure.
	booleanCondition := (self stream contents subStrings: {Character cr}) last = 'self assert: 1 = 2'.
	self assert: booleanCondition! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testAutoAssertTrue
	self assert: 1 = 1.
	self assert: true! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 21:16'!
testAutoDenyFalse
	| booleanCondition |
	self assert: self isLogging.
	self should: [ self deny: 1 = 1 description: 'self deny: 1 = 1'.] raise: TestResult failure.
	booleanCondition := (self stream contents subStrings:  {Character cr}) last = 'self deny: 1 = 1'.
	self assert: booleanCondition! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testAutoDenyTrue
	self deny: 1 = 2.
	self deny: false! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testDifferentExceptionInShouldRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #differentExceptionInShouldRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult passed includes: testCase).
	self assert: testResult errors isEmpty.
	self assert: testResult failures isEmpty.
	self assert: testResult passed size=1! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testErrorInRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #errorInRaiseWithExceptionDoTest.
	testResult := testCase run.
		
	self assert: (testResult errors includes: testCase).
	self assert: testResult errors size=1.
	self assert: testResult failures isEmpty.
	self assert: testResult passed isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'as yet unclassified' stamp: 'md 4/2/2006 14:02'!
testExceptionWithMatchingString
	self should: [ Object obsolete ] raise: Error whoseDescriptionIncludes: 'NOT obsolete' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'as yet unclassified' stamp: 'md 4/2/2006 14:02'!
testExceptionWithoutMatchingString
	self should: [ Object obsolete ] raise: Error whoseDescriptionDoesNotInclude: 'Zero' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'md 8/2/2006 11:06'!
testInvalidShouldNotTakeMoreThan

	| testCase testResult |

	testCase := self class selector: #invalidShouldNotTakeMoreThan.
	testResult := testCase run.

	self assert: testResult passed isEmpty.
	self assert: testResult failures size = 1.
	self assert: (testResult failures includes: testCase).
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testInvalidShouldNotTakeMoreThanMilliseconds

	| testCase testResult |

	testCase := self class selector: #invalidShouldNotTakeMoreThanMilliseconds.
	testResult := testCase run.

	self assert: testResult passed isEmpty.
	self assert: testResult failures size = 1.
	self assert: (testResult failures includes: testCase).
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testNoExceptionInShouldRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #noExceptionInShouldRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult failures includes: testCase).
	self assert: testResult failures size=1.
	self assert: testResult passed isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'as yet unclassified' stamp: 'md 4/2/2006 14:02'!
testNoExceptionWithMatchingString
	self shouldnt: [ Object obsolete ] raise: Error whoseDescriptionIncludes: 'Zero' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'as yet unclassified' stamp: 'md 4/2/2006 14:02'!
testNoExceptionWithNoMatchingString
	self shouldnt: [ Object obsolete ] raise: Error whoseDescriptionDoesNotInclude: 'NOT' description: 'tested obsoleting Object'! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testShouldFix

	| testCase testResult  |
	
	testCase := self class selector: #shouldFixTest.
	testResult := testCase run.
	
	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size=1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'mx 3/20/2006 23:40'!
testShouldRaiseWithExceptionDo

	| testCase testResult  |
	
	testCase := self class selector: #shouldRaiseWithExceptionDoTest.
	testResult := testCase run.
	
	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size=1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty.
	
	! !

!SUnitExtensionsTest methodsFor: 'test' stamp: 'md 8/2/2006 11:06'!
testValidShouldNotTakeMoreThan
	| testCase testResult |

	testCase := self class selector: #validShouldNotTakeMoreThan.
	testResult := testCase run.

	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size = 1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'test' stamp: ''!
testValidShouldNotTakeMoreThanMilliseconds

	| testCase testResult |

	testCase := self class selector: #validShouldNotTakeMoreThanMilliseconds.
	testResult := testCase run.

	self assert: (testResult passed includes: testCase).
	self assert: testResult passed size = 1.
	self assert: testResult failures isEmpty.
	self assert: testResult errors isEmpty

! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: 'md 8/2/2006 11:05'!
validShouldNotTakeMoreThan

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThan:  200 milliSeconds.! !

!SUnitExtensionsTest methodsFor: 'real tests' stamp: ''!
validShouldNotTakeMoreThanMilliseconds

	self should: [(Delay forMilliseconds: 100) wait] notTakeMoreThanMilliseconds: 200! !

TestCase subclass: #SUnitTest
	instanceVariableNames: 'hasRun hasSetup hasRanOnce'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SUnitTest commentStamp: '<historical>' prior: 0!
This is both an example of writing tests and a self test for the SUnit. The tests 
here are pretty strange, since you want to make sure things blow up. You should 
not generally have to write tests this complicated in structure, although they 
will be far more complicated in terms of your own objects- more assertions, more 
complicated setup. Kent says: "Never forget, however, that if the tests are hard 
to write, something is probably wrong with the design".!

!SUnitTest class methodsFor: 'history' stamp: 'AdrianLienhard 10/19/2009 10:49'!
lastStoredRun
	^ ((Dictionary new) add: (#passed->((Set new) add: #testWithExceptionDo; add: #testAssert; add: #testRanOnlyOnce; add: #testDialectLocalizedException; add: #testFail; add: #testDefects; add: #testIsNotRerunOnDebug; add: #testResult; add: #testRunning; add: #testError; add: #testException; add: #testShould; add: #testSuite; yourself)); add: (#timeStamp->'22 November 2008 10:11:35 pm'); add: (#failures->((Set new))); add: (#errors->((Set new))); yourself)! !

!SUnitTest methodsFor: 'private' stamp: ''!
assertForTestResult: aResult runCount: aRunCount passed: aPassedCount failed: aFailureCount errors: anErrorCount

	self
		assert: aResult runCount = aRunCount;
		assert: aResult passedCount = aPassedCount;
		assert: aResult failureCount = aFailureCount;
		assert: aResult errorCount = anErrorCount
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
error
	3 zork
			! !

!SUnitTest methodsFor: 'testing' stamp: 'md 2/22/2006 14:17'!
errorShouldntRaise
	self 
		shouldnt: [self someMessageThatIsntUnderstood] 
		raise: Notification new
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
fail
	self assert: false
			! !

!SUnitTest methodsFor: 'accessing' stamp: ''!
hasRun
	^hasRun
			! !

!SUnitTest methodsFor: 'accessing' stamp: ''!
hasSetup
	^hasSetup
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
noop
			! !

!SUnitTest methodsFor: 'private' stamp: ''!
setRun
	hasRun := true
			! !

!SUnitTest methodsFor: 'running' stamp: ''!
setUp
	hasSetup := true
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testAssert
	self assert: true.
	self deny: false
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testDefects
	| result suite error failure |
	suite := TestSuite new.
	suite addTest: (error := self class selector: #error).
	suite addTest: (failure := self class selector: #fail).
	result := suite run.
	self assert: result defects asArray = (Array with: error with: failure).
	self
		assertForTestResult: result
		runCount: 2
		passed: 0
		failed: 1
		errors: 1
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testDialectLocalizedException

	self
		should: [TestResult signalFailureWith: 'Foo']
		raise: TestResult failure.
	self
		should: [TestResult signalErrorWith: 'Foo']
		raise: TestResult error.

			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testError

	| case result |

	case := self class selector: #error.
	result := case run.
	self
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 0
		errors: 1.

	case := self class selector: #errorShouldntRaise.
	result := case run.
	self 
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 0
		errors: 1
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testException

	self
		should: [self error: 'foo']
		raise: TestResult error
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testFail

	| case result |

	case := self class selector: #fail.
	result := case run.

	self
		assertForTestResult: result
		runCount: 1
		passed: 0
		failed: 1
		errors: 0
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testIsNotRerunOnDebug

	| case |

	case := self class selector: #testRanOnlyOnce.
	case run.
	case debug
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testRanOnlyOnce

	self assert: hasRanOnce ~= true.
	hasRanOnce := true
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testResult

	| case result |

	case := self class selector: #noop.
	result := case run.

	self
		assertForTestResult: result
		runCount: 1
		passed: 1
		failed: 0
		errors: 0
			! !

!SUnitTest methodsFor: 'testing' stamp: 'md 2/22/2006 14:16'!
testRunning

	(Delay forSeconds: 2) wait
			! !

!SUnitTest methodsFor: 'testing' stamp: 'md 2/22/2006 14:19'!
testSelectorWithArg: anObject
	"should not result in error"! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testShould

	self
		should: [true];
		shouldnt: [false]
			! !

!SUnitTest methodsFor: 'testing' stamp: ''!
testSuite

	| suite result |

	suite := TestSuite new.
	suite 
		addTest: (self class selector: #noop);
		addTest: (self class selector: #fail);
		addTest: (self class selector: #error).

	result := suite run.

	self
		assertForTestResult: result
		runCount: 3
		passed: 1
		failed: 1
		errors: 1
			! !

!SUnitTest methodsFor: 'testing' stamp: 'DF 3/17/2006 01:30'!
testWithExceptionDo

	self
		should: [self error: 'foo']
		raise: TestResult error
		withExceptionDo: [:exception |
			self assert: (exception description includesSubString: 'foo')
		]
			! !

TestCase subclass: #SimpleTestResourceTestCase
	instanceVariableNames: 'resource'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SimpleTestResourceTestCase class methodsFor: 'history' stamp: 'AdrianLienhard 10/19/2009 10:49'!
lastStoredRun
	^ ((Dictionary new) add: (#passed->((Set new) add: #testResourceInitRelease; add: #testResourcesCollection; yourself)); add: (#timeStamp->'22 November 2008 10:11:35 pm'); add: (#failures->((Set new))); add: (#errors->((Set new))); yourself)! !

!SimpleTestResourceTestCase class methodsFor: 'not categorized' stamp: ''!
resources
	^Set new add: SimpleTestResource; yourself
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
dummy
	self assert: true
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
error
	'foo' odd
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
fail
	self assert: false
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
setRun
	resource setRun
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
setUp
	resource := SimpleTestResource current
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
testResourceInitRelease
	| result suite error failure |
	suite := TestSuite new.
	suite addTest: (error := self class selector: #error).
	suite addTest: (failure := self class selector: #fail).
	suite addTest: (self class selector: #dummy).
	result := suite run.
	self assert: resource hasSetup
			! !

!SimpleTestResourceTestCase methodsFor: 'not categorized' stamp: ''!
testResourcesCollection
	| collection |
	collection := self resources.
	self assert: collection size = 1
			! !

!TestCase class methodsFor: 'building suites' stamp: 'lr 3/14/2010 21:13'!
addTestsFor: classNameString toSuite: suite
	| cls |
	cls := Smalltalk globals at: classNameString ifAbsent: [ ^ suite ].
	^ cls isAbstract
		ifTrue: [ 
			cls allSubclasses
				do: [ :each | 
					each isAbstract
						ifFalse: [ each addToSuiteFromSelectors: suite ] ].
			suite ]
		ifFalse: [ cls addToSuiteFromSelectors: suite ]! !

!TestCase class methodsFor: 'building suites' stamp: 'nk 4/21/2002 10:51'!
addToSuite: suite fromMethods: testMethods 
	testMethods do:  [ :selector | 
			suite addTest: (self selector: selector) ].
	^suite! !

!TestCase class methodsFor: 'building suites' stamp: 'nk 4/21/2002 16:37'!
addToSuiteFromSelectors: suite
	^self addToSuite: suite fromMethods: (self shouldInheritSelectors
		ifTrue: [ self allTestSelectors ]
		ifFalse: [self testSelectors ])! !

!TestCase class methodsFor: 'accessing' stamp: 'md 2/22/2006 14:28'!
allTestSelectors

	^self allSelectors asSortedCollection asOrderedCollection select: [:each | 
		('test*' match: each) and: [each numArgs isZero]]
			! !

!TestCase class methodsFor: 'building suites' stamp: 'stephaneducasse 2/3/2006 22:41'!
buildSuite
	| suite |
	suite := TestSuite new.
	^ self isAbstract
		ifTrue: [
			suite name: self name asString.
			self allSubclasses
				do: [:each | each isAbstract
						ifFalse: [each addToSuiteFromSelectors: suite]].
			suite]
		ifFalse: [self addToSuiteFromSelectors: suite]! !

!TestCase class methodsFor: 'building suites' stamp: ''!
buildSuiteFromAllSelectors

	^self buildSuiteFromMethods: self allTestSelectors
			! !

!TestCase class methodsFor: 'building suites' stamp: ''!
buildSuiteFromLocalSelectors

	^self buildSuiteFromMethods: self testSelectors
			! !

!TestCase class methodsFor: 'building suites' stamp: 'stephaneducasse 2/3/2006 22:41'!
buildSuiteFromMethods: testMethods 
	| suite |
	suite := (TestSuite new)
				name: self name asString;
				yourself.
	^self addToSuite: suite fromMethods: testMethods! !

!TestCase class methodsFor: 'building suites' stamp: ''!
buildSuiteFromSelectors

	^self shouldInheritSelectors
		ifTrue: [self buildSuiteFromAllSelectors]
		ifFalse: [self buildSuiteFromLocalSelectors]
			! !

!TestCase class methodsFor: 'coverage' stamp: 'lr 3/14/2010 21:13'!
coverage
	"returns the coverage determined by a simple static analysis of test coverage 
	made by the receiver on a class that is identified by the name of the receiver.
	We assume that SetTest test Set."

	| cls className |
	(self name endsWith: 'Test')
		ifFalse: [ self error: 'Please, use #coverageForClass: instead' ].
	className := self name copyFrom: 1 to: self name size - 'Test' size.
	cls := Smalltalk globals at: className asSymbol ifAbsent: [ self error: 'Please, use #coverageForClass: instead' ].	"May happen with Transcript"
	cls isBehavior
		ifFalse: [ cls := cls class ].
	^ self coverageForClass: cls! !

!TestCase class methodsFor: 'coverage' stamp: 'ab 12/25/2008 17:20'!
coverageAsString
	| cov className |
	cov := self coverage first asInteger. 
	"coverage already checks that the name is ends with 'Test' and if the class tested exists"
	
	className := self name copyFrom: 1 to: (self name size - 'Test' size).
	^ self name asString, ' covers ', cov asString, '% of ', className.! !

!TestCase class methodsFor: 'coverage' stamp: 'sd 1/28/2009 14:57'!
coverageForClass: cls
	"returns the test coverage of all the methods included inherited ones"
	^ self coverageForClass: cls until: ProtoObject! !

!TestCase class methodsFor: 'coverage' stamp: 'sd 1/28/2009 14:58'!
coverageForClass: cls until: aRootClass
	"returns the test coverage of all the methods included inherited ones but stopping at aRootClass included"
	
	| definedMethods testedMethods untestedMethods |
	definedMethods := cls allSelectorsAboveUntil: aRootClass.
	definedMethods size = 0
		ifTrue: [^ {0. Set new}].
	testedMethods := 
		self methodDictionary values inject: Set new into: 
							[:sums :cm | sums union: cm messages].
	testedMethods := testedMethods reject: [:sel | (definedMethods includes: sel) not].
	untestedMethods := definedMethods select: [:selector | (testedMethods includes: selector) not].
	^ { (testedMethods size * 100 / definedMethods size) asFloat . untestedMethods}
! !

!TestCase class methodsFor: 'coverage' stamp: 'ab 12/25/2008 17:15'!
coveragePercentage
	^ self coverage first! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
debug: aSymbol

	^(self selector: aSymbol) debug
			! !

!TestCase class methodsFor: 'history' stamp: 'simon.denier 11/13/2008 19:22'!
generateLastStoredRunMethod

	self shouldGenerateLastStoredRunMethod ifTrue: [
		self class
			compile: (self lastRunMethodNamed: #lastStoredRun)
			classified: 'history' ]! !

!TestCase class methodsFor: 'testing' stamp: 'Alexandre.Bergel 4/3/2009 15:06'!
hasMethodBeenRun: aSelector
	^ ((self lastRun at: #errors),
		(self lastRun at: #failures),
		(self lastRun at: #passed))
			includes: aSelector! !

!TestCase class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:57'!
history
	^ history ifNil: [ history := self newTestDictionary ]! !

!TestCase class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:45'!
history: aDictionary
	history := aDictionary! !

!TestCase class methodsFor: 'initialize - event' stamp: 'AlexandreBergel 10/22/2008 13:31'!
initialize
     super initialize.
	SystemChangeNotifier uniqueInstance notify: self ofSystemChangesOfItem: #method using: #methodChanged:.! !

!TestCase class methodsFor: 'testing' stamp: 'md 2/22/2006 14:21'!
isAbstract
	"Override to true if a TestCase subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #TestCase
			! !

!TestCase class methodsFor: 'testing' stamp: 'JorgeRessia 3/16/2010 20:06'!
isUnitTest
	^true! !

!TestCase class methodsFor: 'history' stamp: 'simon.denier 11/22/2008 20:56'!
lastRun
	^ TestResult historyFor: self! !

!TestCase class methodsFor: 'history' stamp: 'simon.denier 11/13/2008 19:21'!
lastRunMethodNamed: aSelector
	
	^ String streamContents: [:str |
		str nextPutAll: aSelector asString ;cr.
		str tab; nextPutAll: '^ ', (self lastRun) storeString]
! !

!TestCase class methodsFor: 'history' stamp: 'AlexandreBergel 10/22/2008 10:33'!
lastStoredRun
	^ ((Dictionary new) add: (#failures->#()); add: (#passed->#()); add: (#errors->#()); yourself)! !

!TestCase class methodsFor: 'coverage' stamp: 'lr 3/14/2010 21:13'!
localCoverage
	"returns the coverage determined by a simple static analysis of test coverage 
	made by the receiver on a class that is identified by the name of the receiver.
	We assume that SetTest test Set. The computation of the coverage takes only into
	account the methods defined locally in the tested class. See coverage for a more global 
	coverage"

	| cls className |
	(self name endsWith: 'Test')
		ifFalse: [ self error: 'Please, use #localCoverageForClass: instead' ].
	className := self name copyFrom: 1 to: self name size - 'Test' size.
	cls := Smalltalk globals at: className asSymbol ifAbsent: [ self error: 'Please, use #localCoverageForClass: instead' ].
	cls isBehavior
		ifFalse: [ cls := cls class ].
	^ self localCoverageForClass: cls! !

!TestCase class methodsFor: 'coverage' stamp: 'sd 1/28/2009 15:04'!
localCoverageAsString
	| cov className |
	cov := self localCoverage first asInteger. 
	"coverage already checks that the name is ends with 'Test' and if the class tested exists"
	
	className := self name copyFrom: 1 to: (self name size - 'Test' size).
	^ self name asString, ' covers ', cov asString, '% of ', className.! !

!TestCase class methodsFor: 'coverage' stamp: 'sd 1/28/2009 14:55'!
localCoverageForClass: cls
	
	| definedMethods testedMethods untestedMethods |
	definedMethods := cls selectors.
	"It happens for IdentityBag / IdentityBagTest"
	definedMethods size = 0
		ifTrue: [^ {0. Set new}].

	testedMethods := 
		self methodDictionary values inject: Set new into: 
							[:sums :cm | sums union: cm messages].
					
	"testedMethods contains all the methods send in test methods, which probably contains methods that have nothign to do with collection"
	testedMethods := testedMethods reject: [:sel | (definedMethods includes: sel) not].

	untestedMethods := definedMethods select: [:selector | (testedMethods includes: selector) not].

	^ { (testedMethods size * 100 / definedMethods size) asFloat . untestedMethods}
! !

!TestCase class methodsFor: 'coverage' stamp: 'sd 1/28/2009 14:55'!
localCoveragePercentage
	^ self localCoverage first! !

!TestCase class methodsFor: 'initialize - event' stamp: 'al 2/9/2009 20:00'!
methodChanged: anEvent
	"Remove the changed method from the known test results."
	
	| cls sel |
	anEvent item isCompiledMethod ifFalse: [ ^ self ].
	cls := anEvent item methodClass.
	(cls inheritsFrom: TestCase)
		ifFalse: [^ self].
	sel := anEvent item selector.
	(sel beginsWith: 'test')
		ifFalse: [^ self].
	TestResult removeFromTestHistory: sel in: cls.
! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 15:58'!
methodFailed: aSelector
	^ (self lastRun at: #failures) includes: aSelector! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 16:00'!
methodPassed: aSelector
	^ (self lastRun at: #passed) includes: aSelector! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 16:00'!
methodProgressed: aSelector
	^ ((self storedMethodRaisedError: aSelector) or: [self storedMethodFailed: aSelector])
		and: [self methodPassed: aSelector]
		! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 16:00'!
methodRaisedError: aSelector
	^ (self lastRun at: #errors) includes: aSelector! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 16:00'!
methodRegressed: aSelector
	^ (self storedMethodPassed: aSelector) and: [(self methodFailed: aSelector) or: [self methodRaisedError: aSelector]]! !

!TestCase class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:57'!
newTestDictionary

	^ Dictionary new at: #timeStamp put: TimeStamp now;
		at: #passed put: Set new;
		at: #failures put: Set new;
		at: #errors put: Set new;
		yourself
		! !

!TestCase class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:47'!
resetHistory
	history := nil! !

!TestCase class methodsFor: 'accessing' stamp: ''!
resources

	^#()
			! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
run: aSymbol

	^(self selector: aSymbol) run
			! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
selector: aSymbol

	^self new setTestSelector: aSymbol
			! !

!TestCase class methodsFor: 'history' stamp: 'simon.denier 11/13/2008 21:29'!
shouldGenerateLastStoredRunMethod
	| sameRun |
	
	(self class methodDictionary includesKey: #lastStoredRun)
		ifFalse: [^ true].
	sameRun := #(#passed #failures #errors) inject: true into: 
		[ :ok :set | ok and: [(self lastRun at: set) = (self lastStoredRun at: set) ]].
	^ sameRun not
! !

!TestCase class methodsFor: 'testing' stamp: ''!
shouldInheritSelectors
	"I should inherit from an Abstract superclass but not from a concrete one by default, unless I have no testSelectors in which case I must be expecting to inherit them from my superclass.  If a test case with selectors wants to inherit selectors from a concrete superclass, override this to true in that subclass."

	^self superclass isAbstract
		or: [self testSelectors isEmpty]

"$QA Ignore:Sends system method(superclass)$"
			! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 15:59'!
storedMethodFailed: aSelector
	^ (self lastStoredRun at: #failures) includes: aSelector! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 16:00'!
storedMethodPassed: aSelector
	^ (self lastStoredRun at: #passed) includes: aSelector! !

!TestCase class methodsFor: 'testing' stamp: 'AlexandreBergel 10/21/2008 15:59'!
storedMethodRaisedError: aSelector
	^ (self lastStoredRun at: #errors) includes: aSelector! !

!TestCase class methodsFor: 'instance creation' stamp: ''!
suite

	^self buildSuite
			! !

!TestCase class methodsFor: 'building suites' stamp: ''!
suiteClass
	^TestSuite
			! !

!TestCase class methodsFor: 'accessing' stamp: ''!
sunitVersion
	^'3.1'
			! !

!TestCase class methodsFor: 'accessing' stamp: 'StephaneDucasse 2/27/2010 16:28'!
testSelectors 
	
	^(self selectors asArray select: [ :each |
		(each beginsWith: 'test') and: [ each numArgs isZero ] ]) sort! !

!TestCase methodsFor: 'dependencies' stamp: ''!
addDependentToHierachy: anObject 
	"an empty method. for Composite compability with TestSuite"


			! !

!TestCase methodsFor: 'accessing' stamp: 'jannik.laval 5/2/2010 07:06'!
assert: aBoolean

	aBoolean ifFalse: [self signalFailure: 'Assertion failed']
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
assert: aBooleanOrBlock description: aString
	aBooleanOrBlock value ifFalse: [
		self logFailure: aString.
		TestResult failure signal: aString]
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
assert: aBooleanOrBlock description: aString resumable: resumableBoolean 
	| exception |
	aBooleanOrBlock value
		ifFalse: 
			[self logFailure: aString.
			exception := resumableBoolean
						ifTrue: [TestResult resumableFailure]
						ifFalse: [TestResult failure].
			exception signal: aString]
			! !

!TestCase methodsFor: 'accessing' stamp: 'dc 4/2/2007 18:38'!
assert: expected equals: actual
	^ self
		assert: (expected = actual)
		description: (self comparingStringBetween: expected and: actual)
! !

!TestCase methodsFor: 'private' stamp: 'AdrianLienhard 10/19/2009 12:07'!
cleanUpInstanceVariables
	self class allInstVarNames do: [ :name |
		name = 'testSelector' ifFalse: [
			self instVarNamed: name put: nil ] ]! !

!TestCase methodsFor: 'private' stamp: 'dc 4/2/2007 18:46'!
comparingStringBetween: expected and: actual
	^ String streamContents: [:stream |
		stream
			nextPutAll: 'Expected ';
			nextPutAll: (expected printStringLimitedTo: 10);
			nextPutAll: ' but was ';
			nextPutAll: (actual printStringLimitedTo: 10);
			nextPutAll: '.'
		]! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
debug
	self resources do: [:res | 
		res isAvailable ifFalse: [^res signalInitializationError]].
	[(self class selector: testSelector) runCase] 
		ensure: [self resources do: [:each | each reset]]
			! !

!TestCase methodsFor: 'running' stamp: 'bp 11/15/2004 18:13'!
debugAsFailure
	| semaphore |
	semaphore := Semaphore new.
	self resources do: [:res | 
		res isAvailable ifFalse: [^res signalInitializationError]].
	[semaphore wait. self resources do: [:each | each reset]] fork.
	(self class selector: testSelector) runCaseAsFailure: semaphore.! !

!TestCase methodsFor: 'accessing' stamp: 'jannik.laval 5/2/2010 07:16'!
deny: aBoolean

	self assert: aBoolean not
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
deny: aBooleanOrBlock description: aString
	self assert: aBooleanOrBlock value not description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: 'md 8/2/2006 11:00'!
deny: aBooleanOrBlock description: aString resumable: resumableBoolean 
	self
		assert: aBooleanOrBlock value not
		description: aString
		resumable: resumableBoolean
			! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:27'!
executeShould: aBlock inScopeOf: anExceptionalEvent 
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: true]
			! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:27'!
executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: aString
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: (ex description includesSubString: aString) ]
			! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:27'!
executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: aString
	^[aBlock value.
 	false] on: anExceptionalEvent
		do: [:ex | ex return: (ex description includesSubString: aString) not ]
			! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/20/2006 23:32'!
executeShould: aBlock inScopeOf: anException withExceptionDo: anotherBlock

	^[aBlock value.
 	false] 
		on: anException
		do: [:exception | 
			anotherBlock value: exception.
			exception return: true]! !

!TestCase methodsFor: 'testing' stamp: 'JF 7/30/2003 13:40'!
expectedFailures
	^ Array new! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/13/2006 23:21'!
fail

	^self assert: false! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:17'!
failureLog	
	^Transcript

			! !

!TestCase methodsFor: 'running' stamp: ''!
isLogging
	"By default, we're not logging failures. If you override this in 
	a subclass, make sure that you override #failureLog"
	^false
			! !

!TestCase methodsFor: 'running' stamp: ''!
logFailure: aString
	self isLogging ifTrue: [
		self failureLog 
			cr; 
			nextPutAll: aString; 
			flush]
			! !

!TestCase methodsFor: 'running' stamp: 'bp 11/15/2004 18:17'!
openDebuggerOnFailingTestMethod
	"SUnit has halted one step in front of the failing test method. Step over the 'self halt' and 
	 send into 'self perform: testSelector' to see the failure from the beginning"

	self
		halt;
		performTest! !

!TestCase methodsFor: 'private' stamp: 'md 2/22/2006 14:22'!
performTest

	self perform: testSelector asSymbol
			! !

!TestCase methodsFor: 'printing' stamp: ''!
printOn: aStream

	aStream
		nextPutAll: self class printString;
		nextPutAll: '>>#';
		nextPutAll: testSelector
			! !

!TestCase methodsFor: 'dependencies' stamp: ''!
removeDependentFromHierachy: anObject 
	"an empty method. for Composite compability with TestSuite"


			! !

!TestCase methodsFor: 'accessing' stamp: ''!
resources
	| allResources resourceQueue |
	allResources := Set new.
	resourceQueue := OrderedCollection new.
	resourceQueue addAll: self class resources.
	[resourceQueue isEmpty] whileFalse: [
		| next |
		next := resourceQueue removeFirst.
		allResources add: next.
		resourceQueue addAll: next resources].
	^allResources
			! !

!TestCase methodsFor: 'running' stamp: ''!
run
	| result |
	result := TestResult new.
	self run: result.
	^result
			! !

!TestCase methodsFor: 'running' stamp: 'GwenaelCasaccio 10/1/2008 19:58'!
run: aResult 
	aResult runCase: self.
! !

!TestCase methodsFor: 'running' stamp: 'AdrianLienhard 1/21/2010 22:03'!
runCase
	[self setUp.
	self performTest]
		ensure: [
			self tearDown.
			self cleanUpInstanceVariables ]! !

!TestCase methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
runCaseAsFailure: aSemaphore
	[self setUp.
	self openDebuggerOnFailingTestMethod] ensure: [
		self tearDown.
		aSemaphore signal]! !

!TestCase methodsFor: 'accessing' stamp: ''!
selector
	^testSelector
			! !

!TestCase methodsFor: 'private' stamp: ''!
setTestSelector: aSymbol
	testSelector := aSymbol
			! !

!TestCase methodsFor: 'running' stamp: 'DavidRoethlisberger 11/10/2008 09:54'!
setUp! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock
	self assert: aBlock value
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock description: aString
	self assert: aBlock value description: aString
			! !

!TestCase methodsFor: 'extensions' stamp: 'md 8/2/2006 11:09'!
should: aBlock notTakeMoreThan: aDuration
    "Evaluate aBlock in a forked process and if it takes more than anInteger milliseconds
    to run we terminate the process and report a test failure.  It'' important to
    use the active process for the test failure so that the failure reporting works correctly
    in the context of the exception handlers."

    | evaluated evaluationProcess result delay testProcess |

    evaluated := false.
    delay := Delay forDuration: aDuration.
    testProcess := Processor activeProcess.
    "Create a new process to evaluate aBlock"
    evaluationProcess := [
        result := aBlock value.
        evaluated := true.
        delay unschedule.
        testProcess resume ] forkNamed: 'Process to evaluate should: notTakeMoreThanMilliseconds:'.

    "Wait the milliseconds they asked me to"
    delay wait.
    "After this point either aBlock was evaluated or not..."
    evaluated ifFalse: [
        evaluationProcess terminate.
        self assert: false description: ('Block evaluation took more than the expected <1p>' expandMacrosWith: aDuration)].
   
    ^result! !

!TestCase methodsFor: 'extensions' stamp: 'md 8/2/2006 11:08'!
should: aBlock notTakeMoreThanMilliseconds: anInteger
    "For compatibility with other Smalltalks"

   self should: aBlock notTakeMoreThan: (Duration milliSeconds: anInteger).! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock raise: anExceptionalEvent 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent)
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
should: aBlock raise: anExceptionalEvent description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent)
		description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:32'!
should: aBlock raise: anExceptionalEvent whoseDescriptionDoesNotInclude: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: subString)
		description: aString
! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:24'!
should: aBlock raise: anExceptionalEvent whoseDescriptionIncludes: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: subString)
		description: aString
! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/20/2006 23:52'!
should: aBlock raise: anException withExceptionDo: anotherBlock 

	^self assert: (self executeShould: aBlock inScopeOf: anException withExceptionDo: anotherBlock)! !

!TestCase methodsFor: 'extensions' stamp: 'mx 3/20/2006 21:29'!
shouldFix: aBlock 

	^self should: aBlock raise: Exception! !

!TestCase methodsFor: 'testing' stamp: 'JF 7/30/2003 13:39'!
shouldPass
	"Unless the selector is in the list we get from #expectedFailures, we expect it to pass"
	^ (self expectedFailures includes: testSelector) not! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock
	self deny: aBlock value
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock description: aString
	self deny: aBlock value description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock raise: anExceptionalEvent 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent) not
			! !

!TestCase methodsFor: 'accessing' stamp: ''!
shouldnt: aBlock raise: anExceptionalEvent description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent) not 		description: aString
			! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:34'!
shouldnt: aBlock raise: anExceptionalEvent whoseDescriptionDoesNotInclude: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionNotContaining: subString) not
		description: aString
! !

!TestCase methodsFor: 'accessing' stamp: 'nk 5/11/2003 10:34'!
shouldnt: aBlock raise: anExceptionalEvent whoseDescriptionIncludes: subString description: aString 
	^self assert: (self executeShould: aBlock inScopeOf: anExceptionalEvent withDescriptionContaining: subString) not
		description: aString
! !

!TestCase methodsFor: 'accessing' stamp: 'md 2/22/2006 14:26'!
signalFailure: aString
	TestResult failure signal: aString! !

!TestCase methodsFor: 'running' stamp: 'DavidRoethlisberger 11/10/2008 09:54'!
tearDown! !

TestCase subclass: #TestCaseTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!TestCaseTest methodsFor: 'testing' stamp: 'JorgeRessia 3/16/2010 20:57'!
testIsUnitTest

	self assert: TestCase isUnitTest! !

Object subclass: #TestResource
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

TestResource class
	instanceVariableNames: 'current'!

TestResource class
	instanceVariableNames: 'current'!

TestResource subclass: #SimpleTestResource
	instanceVariableNames: 'runningState hasRun hasSetup hasRanOnce'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Tests'!

!SimpleTestResource methodsFor: 'testing' stamp: ''!
hasRun
	^hasRun
			! !

!SimpleTestResource methodsFor: 'testing' stamp: ''!
hasSetup
	^hasSetup
			! !

!SimpleTestResource methodsFor: 'testing' stamp: ''!
isAvailable
	
	^self runningState == self startedStateSymbol
			! !

!SimpleTestResource methodsFor: 'accessing' stamp: ''!
runningState

	^runningState
			! !

!SimpleTestResource methodsFor: 'accessing' stamp: ''!
runningState: aSymbol

	runningState := aSymbol
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
setRun
	hasRun := true
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
setUp
	
	self runningState: self startedStateSymbol.
	hasSetup := true
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
startedStateSymbol

	^#started
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
stoppedStateSymbol

	^#stopped
			! !

!SimpleTestResource methodsFor: 'running' stamp: ''!
tearDown

	self runningState: self stoppedStateSymbol
			! !

!TestResource class methodsFor: 'accessing' stamp: ''!
current

	current isNil
		ifTrue: [current := self new].

	^current
			! !

!TestResource class methodsFor: 'accessing' stamp: ''!
current: aTestResource

	current := aTestResource
			! !

!TestResource class methodsFor: 'testing' stamp: 'md 2/22/2006 14:21'!
isAbstract
	"Override to true if a TestResource subclass is Abstract and should not have
	TestCase instances built from it"

	^self name = #TestResource
			! !

!TestResource class methodsFor: 'testing' stamp: ''!
isAvailable
	^self current notNil and: [self current isAvailable]
			! !

!TestResource class methodsFor: 'testing' stamp: ''!
isUnavailable

	^self isAvailable not
			! !

!TestResource class methodsFor: 'creation' stamp: ''!
reset

	current notNil ifTrue: [
		[current tearDown] ensure: [
			current := nil]]
			! !

!TestResource class methodsFor: 'accessing' stamp: ''!
resources
	^#()
			! !

!TestResource class methodsFor: 'creation' stamp: ''!
signalInitializationError
	^TestResult signalErrorWith: 'Resource ' , self name , ' could not be initialized'
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
description

	description isNil
		ifTrue: [^''].

	^description
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
description: aString

	description := aString
			! !

!TestResource methodsFor: 'initializing' stamp: 'alain.plantec 5/28/2009 11:11'!
initialize
	super initialize.
	self setUp

			! !

!TestResource methodsFor: 'testing' stamp: ''!
isAvailable
	"override to provide information on the
	readiness of the resource"
	
	^true
			! !

!TestResource methodsFor: 'testing' stamp: ''!
isUnavailable
	"override to provide information on the
	readiness of the resource"
	
	^self isAvailable not
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
name

	name isNil
		ifTrue: [^self printString].

	^name
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
name: aString

	name := aString
			! !

!TestResource methodsFor: 'printing' stamp: ''!
printOn: aStream

	aStream nextPutAll: self class printString
			! !

!TestResource methodsFor: 'accessing' stamp: ''!
resources
	^self class resources
			! !

!TestResource methodsFor: 'running' stamp: ''!
setUp
	"Does nothing. Subclasses should override this
	to initialize their resource"
			! !

!TestResource methodsFor: 'running' stamp: ''!
signalInitializationError
	^self class signalInitializationError
			! !

!TestResource methodsFor: 'running' stamp: ''!
tearDown
	"Does nothing. Subclasses should override this
	to tear down their resource"
			! !

Object subclass: #TestResult
	instanceVariableNames: 'timeStamp failures errors passed'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestResult commentStamp: '<historical>' prior: 0!
This is a Collecting Parameter for the running of a bunch of tests. TestResult is an interesting object to subclass or substitute. #runCase: is the external protocol you need to reproduce. Kent has seen TestResults that recorded coverage information and that sent email when they were done.!

!TestResult class methodsFor: 'exceptions' stamp: ''!
error
	^self exError
			! !

!TestResult class methodsFor: 'exceptions' stamp: 'md 2/22/2006 14:17'!
exError
	^Error
			! !

!TestResult class methodsFor: 'exceptions' stamp: ''!
failure
	^TestFailure
			! !

!TestResult class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:44'!
historyAt: aTestCaseClass
"I will return the last test dictionary for aTestCaseClass. If none found, I will create a new empty one and link it in the history."

	^ aTestCaseClass history ! !

!TestResult class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:45'!
historyAt: aTestCaseClass put: aDictionary
	aTestCaseClass history: aDictionary
	"^ self history at: aTestCaseClass put: aDictionary "! !

!TestResult class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:46'!
historyFor: aTestCaseClass
	"I return the last test dictionary for aTestCaseClass. 
	If none found, I return an empty dictionary but will not link it to the class in the history."
	
	| history |
	history := aTestCaseClass history.
	history ifNil: [ ^ self newTestDictionary ].
	^ history
	
"	^ self history at: aTestCaseClass ifAbsent: [ self newTestDictionary ]"! !

!TestResult class methodsFor: 'history' stamp: 'Alexandre.Bergel 4/3/2009 14:10'!
newTestDictionary

	^ Dictionary new at: #timeStamp put: TimeStamp now;
		at: #passed put: Set new;
		at: #failures put: Set new;
		at: #errors put: Set new;
		yourself
		! !

!TestResult class methodsFor: 'history' stamp: 'simon.denier 11/22/2008 20:56'!
removeFromTestHistory: aSelector in: aTestCaseClass
	| lastRun |
	
	lastRun := self historyFor: aTestCaseClass.
	#(#passed #failures #errors) do:
		[ :set | (lastRun at: set) remove: aSelector ifAbsent: []].
! !

!TestResult class methodsFor: 'exceptions' stamp: ''!
resumableFailure
	^ResumableTestFailure
			! !

!TestResult class methodsFor: 'exceptions' stamp: 'md 2/22/2006 14:26'!
signalErrorWith: aString 
	self error signal: aString
			! !

!TestResult class methodsFor: 'exceptions' stamp: 'md 2/22/2006 14:26'!
signalFailureWith: aString 
	self failure signal: aString
			! !

!TestResult class methodsFor: 'history' stamp: 'simon.denier 11/22/2008 22:05'!
updateTestHistoryFor: aTestCase status: aSymbol
	| cls sel |
	
	cls := aTestCase class.
	sel := aTestCase selector.
	self removeFromTestHistory: sel in: cls.
	((self historyAt: cls) at: aSymbol ) add: sel! !

!TestResult methodsFor: 'accessing' stamp: 'simon.denier 11/13/2008 20:27'!
classesTested
	^ (self tests collect: [ :testCase | testCase class ]) asSet! !

!TestResult methodsFor: 'accessing' stamp: ''!
correctCount
	"depreciated - use #passedCount"

	^self passedCount
			! !

!TestResult methodsFor: 'accessing' stamp: ''!
defects
	^OrderedCollection new
		addAll: self errors;
		addAll: self failures; yourself
			! !

!TestResult methodsFor: 'diff' stamp: 'AlexandreBergel 10/1/2008 16:26'!
diff: aTestResult
	"Return a collection that contains differences"
	| passed1Selectors failed1Selectors errors1Selectors passed2Selectors failed2Selectors errors2Selectors |
	passed1Selectors := self passed collect: [:testCase | testCase selector].
	failed1Selectors := self failures collect: [:testCase | testCase selector].
	errors1Selectors := self errors collect: [:testCase | testCase selector].

	passed2Selectors := aTestResult passed collect: [:testCase | testCase selector].
	failed2Selectors := aTestResult failures collect: [:testCase | testCase selector].
	errors2Selectors := aTestResult errors collect: [:testCase | testCase selector].
	
	^ {passed1Selectors copyWithoutAll: passed2Selectors .
		failed1Selectors copyWithoutAll: failed2Selectors .
		errors1Selectors copyWithoutAll: errors2Selectors}! !

!TestResult methodsFor: 'history' stamp: 'simon.denier 11/13/2008 20:33'!
dispatchResultsIntoHistory 

	self classesTested do: 
		[ :testClass | 
		self class
			historyAt: testClass
			put: (self selectResultsForTestCase: testClass) ].
! !

!TestResult methodsFor: 'accessing' stamp: ''!
errorCount

	^self errors size
			! !

!TestResult methodsFor: 'compatibility' stamp: 'JF 7/30/2003 16:09'!
errors
	^ self unexpectedErrors! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
expectedDefectCount
	^ self expectedDefects size! !

!TestResult methodsFor: 'accessing' stamp: 'md 11/25/2004 16:36'!
expectedDefects
	^ (errors, failures asOrderedCollection) select: [:each | each shouldPass not] ! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
expectedPassCount
	^ self expectedPasses size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
expectedPasses
	^ passed select: [:each | each shouldPass] ! !

!TestResult methodsFor: 'accessing' stamp: ''!
failureCount

	^self failures size
			! !

!TestResult methodsFor: 'compatibility' stamp: 'md 11/25/2004 16:23'!
failures
	^ self unexpectedFailures, self unexpectedPasses ! !

!TestResult methodsFor: 'testing' stamp: ''!
hasErrors

	^self errors size > 0
			! !

!TestResult methodsFor: 'testing' stamp: ''!
hasFailures

	^self failures size > 0
			! !

!TestResult methodsFor: 'testing' stamp: 'jf 3/4/2009 11:55'!
hasPassed
	^ self hasErrors not and: [ self hasFailures not ]! !

!TestResult methodsFor: 'initialization' stamp: 'alain.plantec 5/28/2009 11:11'!
initialize
	super initialize.
	passed := OrderedCollection new.
	failures := Set new.
	errors := OrderedCollection new.
	timeStamp := TimeStamp now! !

!TestResult methodsFor: 'testing' stamp: ''!
isError: aTestCase

	^self errors includes: aTestCase
			! !

!TestResult methodsFor: 'querying' stamp: 'GwenaelCasaccio 10/1/2008 22:37'!
isErrorFor: class selector: selector
	^ self errors anySatisfy: [:testCase | testCase class == class and: [testCase selector == selector]]! !

!TestResult methodsFor: 'testing' stamp: ''!
isFailure: aTestCase
	^self failures includes: aTestCase
			! !

!TestResult methodsFor: 'querying' stamp: 'GwenaelCasaccio 10/1/2008 22:37'!
isFailureFor: class selector: selector
	^ self failures anySatisfy: [:testCase | testCase class == class and: [testCase selector == selector]]! !

!TestResult methodsFor: 'testing' stamp: ''!
isPassed: aTestCase

	^self passed includes: aTestCase
			! !

!TestResult methodsFor: 'querying' stamp: 'GwenaelCasaccio 10/1/2008 22:36'!
isPassedFor: class selector: selector
	^ self passed anySatisfy: [:testCase | testCase class == class and: [testCase selector == selector]]! !

!TestResult methodsFor: 'compatibility' stamp: 'JF 7/30/2003 16:08'!
passed
	^ self expectedPasses, self expectedDefects! !

!TestResult methodsFor: 'accessing' stamp: ''!
passedCount

	^self passed size
			! !

!TestResult methodsFor: 'printing' stamp: 'JF 7/30/2003 16:15'!
printOn: aStream
	aStream
		nextPutAll: self runCount printString;
		nextPutAll: ' run, ';
		nextPutAll: self expectedPassCount printString;
		nextPutAll: ' passes, ';
		nextPutAll: self expectedDefectCount printString;
		nextPutAll:' expected failures, ';
		nextPutAll: self unexpectedFailureCount printString;
		nextPutAll: ' failures, ';
		nextPutAll: self unexpectedErrorCount printString;
		nextPutAll:' errors, ';
		nextPutAll: self unexpectedPassCount printString;
		nextPutAll:' unexpected passes'.! !

!TestResult methodsFor: 'running' stamp: 'md 2/22/2006 14:27'!
runCase: aTestCase
	| testCasePassed |
	testCasePassed := true.
	[[aTestCase runCase] 
			on: self class failure
			do: 
				[:signal | 
				failures add: aTestCase.
				testCasePassed := false.
				signal return: false]]
					on: self class error
					do:
						[:signal |
						errors add: aTestCase.
						testCasePassed := false.
						signal return: false].
	testCasePassed ifTrue: [passed add: aTestCase]! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:07'!
runCount
	^ passed size + failures size + errors size! !

!TestResult methodsFor: 'history' stamp: 'simon.denier 11/13/2008 20:51'!
selectResultsForTestCase: aTestCaseClass
	| passedSelectors errorsSelectors failuresSelectors |
	passedSelectors := self passed
						select: [:testCase | testCase class == aTestCaseClass ] thenCollect: [:testCase | testCase selector].
	errorsSelectors := self errors 
						select: [:testCase | testCase class == aTestCaseClass ] thenCollect:  [:testCase | testCase selector].
	failuresSelectors := self failures 
						select: [:testCase | testCase class == aTestCaseClass ] thenCollect:  [:testCase | testCase selector].
	
	^ self class newTestDictionary 
		at: #passed put: passedSelectors asSet;
		at: #failures put: failuresSelectors asSet;
		at: #errors put: errorsSelectors asSet;
		yourself
		! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:06'!
tests
	^(OrderedCollection new: self runCount)
		addAll: passed;
		addAll: failures;
		addAll: errors;
		yourself! !

!TestResult methodsFor: 'accessing' stamp: 'AlexandreBergel 10/1/2008 11:52'!
timeStamp
	^ timeStamp! !

!TestResult methodsFor: 'accessing' stamp: 'AlexandreBergel 10/1/2008 11:52'!
timeStamp: anObject
	timeStamp := anObject! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
unexpectedErrorCount
	^ self unexpectedErrors size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
unexpectedErrors
	^ errors select: [:each | each shouldPass] ! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
unexpectedFailureCount
	^ self unexpectedFailures size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
unexpectedFailures
	^ failures select: [:each | each shouldPass] ! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 13:54'!
unexpectedPassCount
	^ self unexpectedPasses size! !

!TestResult methodsFor: 'accessing' stamp: 'JF 7/30/2003 16:14'!
unexpectedPasses
	^ passed select: [:each | each shouldPass not] ! !

!TestResult methodsFor: 'history' stamp: 'simon.denier 11/22/2008 22:05'!
updateResultsInHistory
	
	#(#passed #failures #errors) do: [ :status | 
		(self perform: status) do: [ :testCase | 
			self class updateTestHistoryFor: testCase status: status ] ]! !

Object subclass: #TestSuite
	instanceVariableNames: 'tests resources name'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SUnit-Kernel'!

!TestSuite commentStamp: '<historical>' prior: 0!
This is a Composite of Tests, either TestCases or other TestSuites. The common protocol is #run: aTestResult and the dependencies protocol!

!TestSuite class methodsFor: 'instance creation' stamp: ''!
named: aString

	^self new
		name: aString;
		yourself
			! !

!TestSuite methodsFor: 'dependencies' stamp: 'md 2/22/2006 14:24'!
addDependentToHierachy: anObject
	self addDependent: anObject.
	self tests do: [ :each | each addDependentToHierachy: anObject]
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
addTest: aTest
	self tests add: aTest
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
addTests: aCollection 
	aCollection do: [:eachTest | self addTest: eachTest]
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
defaultResources
	^self tests 
		inject: Set new
		into: [:coll :testCase | 
			coll
				addAll: testCase resources;
				yourself]
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
name

	^name
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
name: aString

	name := aString
			! !

!TestSuite methodsFor: 'dependencies' stamp: 'md 2/22/2006 14:24'!
removeDependentFromHierachy: anObject
	self removeDependent: anObject.
	self tests do: [ :each | each removeDependentFromHierachy: anObject]
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
resources
	resources isNil ifTrue: [resources := self defaultResources].
	^resources
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
resources: anObject
	resources := anObject
			! !

!TestSuite methodsFor: 'running' stamp: 'stephane.ducasse 10/9/2008 18:36'!
run
	| result |
 	result := TestResult new.
	self resources do: [ :res |
		res isAvailable ifFalse: [^res signalInitializationError]].
	[self run: result] ensure: [self resources do: [:each | each reset]].
	^result
			! !

!TestSuite methodsFor: 'running' stamp: 'stephane.ducasse 10/9/2008 18:36'!
run: aResult 
	self tests do: [:each | 
		self changed: each.
		each run: aResult].
			! !

!TestSuite methodsFor: 'accessing' stamp: ''!
tests
	tests isNil ifTrue: [tests := OrderedCollection new].
	^tests
			! !
TestCase initialize!
LongTestCase initialize!
